==> jc-1.4.0.tar.gz: soot/jimple/toolkits/typing/TypeAssigner.h <==
// public class soot.jimple.toolkits.typing.TypeAssigner

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a76a7734eb62f430 soot_BodyTransformer
// @dep_class de5fa3182955e270 soot_Transformer
// @dep_class b975ed28388dbed1 soot_jimple_toolkits_typing_TypeAssigner

// header file dependencies
// @dep_header soot_BodyTransformer

#include "soot/BodyTransformer.h"

#ifndef _JC_soot_jimple_toolkits_typing_TypeAssigner_H_
#define _JC_soot_jimple_toolkits_typing_TypeAssigner_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Body$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_jimple_JimpleBody$object;
struct _jc_soot_jimple_toolkits_typing_TypeAssigner$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_typing_TypeAssigner$sub_refs	_jc_soot_jimple_toolkits_typing_TypeAssigner$sub_refs;
typedef struct _jc_soot_jimple_toolkits_typing_TypeAssigner$sub_nonrefs	_jc_soot_jimple_toolkits_typing_TypeAssigner$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_typing_TypeAssigner$refs	_jc_soot_jimple_toolkits_typing_TypeAssigner$refs;
typedef struct _jc_soot_jimple_toolkits_typing_TypeAssigner$nonrefs	_jc_soot_jimple_toolkits_typing_TypeAssigner$nonrefs;
typedef struct _jc_soot_jimple_toolkits_typing_TypeAssigner$object	_jc_soot_jimple_toolkits_typing_TypeAssigner$object;

typedef const struct _jc_soot_jimple_toolkits_typing_TypeAssigner$vmethods	_jc_soot_jimple_toolkits_typing_TypeAssigner$vmethods;
typedef const struct _jc_soot_jimple_toolkits_typing_TypeAssigner$vtable	_jc_soot_jimple_toolkits_typing_TypeAssigner$vtable;
typedef const struct _jc_soot_jimple_toolkits_typing_TypeAssigner$vtype	_jc_soot_jimple_toolkits_typing_TypeAssigner$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_typing_TypeAssigner$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_jimple_toolkits_typing_TypeAssigner$object *, struct _jc_soot_Singletons__24Global$object *);

// Virtual methods
extern void _jc_soot_jimple_toolkits_typing_TypeAssigner$method$internalTransform$9abd4924859b68a3(_jc_env *, struct _jc_soot_jimple_toolkits_typing_TypeAssigner$object *, struct _jc_soot_Body$object *, struct _jc_java_lang_String$object *, struct _jc_object *);
extern jboolean _jc_soot_jimple_toolkits_typing_TypeAssigner$method$typingFailed$1ce2325cbac8a787(_jc_env *, struct _jc_soot_jimple_toolkits_typing_TypeAssigner$object *, struct _jc_soot_jimple_JimpleBody$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_typing_TypeAssigner$method_info$internalTransform$9abd4924859b68a3;
extern _jc_method _jc_soot_jimple_toolkits_typing_TypeAssigner$method_info$typingFailed$1ce2325cbac8a787;

// Static methods
extern struct _jc_soot_jimple_toolkits_typing_TypeAssigner$object *_jc_soot_jimple_toolkits_typing_TypeAssigner$method$v$ddfa867c9204e3c5(_jc_env *);

// Virtual methods structure
struct _jc_soot_jimple_toolkits_typing_TypeAssigner$vmethods {
	void	(*internalTransform$9abd4924859b68a3)(_jc_env *, struct _jc_soot_jimple_toolkits_typing_TypeAssigner$object *, struct _jc_soot_Body$object *, struct _jc_java_lang_String$object *, struct _jc_object *);
	jboolean	(*typingFailed$1ce2325cbac8a787)(_jc_env *, struct _jc_soot_jimple_toolkits_typing_TypeAssigner$object *, struct _jc_soot_jimple_JimpleBody$object *);
};

// Vtable
struct _jc_soot_jimple_toolkits_typing_TypeAssigner$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Transformer$vmethods	soot_Transformer;
	_jc_soot_BodyTransformer$vmethods	soot_BodyTransformer;
	_jc_soot_jimple_toolkits_typing_TypeAssigner$vmethods	soot_jimple_toolkits_typing_TypeAssigner;
};

// Vtype
struct _jc_soot_jimple_toolkits_typing_TypeAssigner$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_typing_TypeAssigner$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_typing_TypeAssigner$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_typing_TypeAssigner$refs {
    _jc_soot_jimple_toolkits_typing_TypeAssigner$sub_refs	soot_jimple_toolkits_typing_TypeAssigner;
    _jc_soot_BodyTransformer$sub_refs	soot_BodyTransformer;
    _jc_soot_Transformer$sub_refs	soot_Transformer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_typing_TypeAssigner$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_typing_TypeAssigner$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Transformer$sub_nonrefs	soot_Transformer;
    _jc_soot_BodyTransformer$sub_nonrefs	soot_BodyTransformer;
    _jc_soot_jimple_toolkits_typing_TypeAssigner$sub_nonrefs	soot_jimple_toolkits_typing_TypeAssigner;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_typing_TypeAssigner$object {
	_jc_soot_jimple_toolkits_typing_TypeAssigner$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_typing_TypeAssigner$vtype	*vtype;
	_jc_soot_jimple_toolkits_typing_TypeAssigner$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_typing_TypeAssigner$vtype _jc_soot_jimple_toolkits_typing_TypeAssigner$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_typing_TypeAssigner, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_typing_TypeAssigner$class_object;

#endif	/* _JC_soot_jimple_toolkits_typing_TypeAssigner_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/typing/TypeAssigner.h <==
// public class soot.jimple.toolkits.typing.TypeAssigner

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class a76a7734eb62f430 soot_BodyTransformer
// @dep_class de5fa3182955e270 soot_Transformer
// @dep_class b975ed28388dbed1 soot_jimple_toolkits_typing_TypeAssigner

// header file dependencies
// @dep_header soot_BodyTransformer

#include "soot/BodyTransformer.h"

#ifndef _JC_soot_jimple_toolkits_typing_TypeAssigner_H_
#define _JC_soot_jimple_toolkits_typing_TypeAssigner_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Body$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_jimple_JimpleBody$object;
struct _jc_soot_jimple_toolkits_typing_TypeAssigner$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_typing_TypeAssigner$sub_refs	_jc_soot_jimple_toolkits_typing_TypeAssigner$sub_refs;
typedef struct _jc_soot_jimple_toolkits_typing_TypeAssigner$sub_nonrefs	_jc_soot_jimple_toolkits_typing_TypeAssigner$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_typing_TypeAssigner$refs	_jc_soot_jimple_toolkits_typing_TypeAssigner$refs;
typedef struct _jc_soot_jimple_toolkits_typing_TypeAssigner$nonrefs	_jc_soot_jimple_toolkits_typing_TypeAssigner$nonrefs;
typedef struct _jc_soot_jimple_toolkits_typing_TypeAssigner$object	_jc_soot_jimple_toolkits_typing_TypeAssigner$object;

typedef const struct _jc_soot_jimple_toolkits_typing_TypeAssigner$vmethods	_jc_soot_jimple_toolkits_typing_TypeAssigner$vmethods;
typedef const struct _jc_soot_jimple_toolkits_typing_TypeAssigner$vtable	_jc_soot_jimple_toolkits_typing_TypeAssigner$vtable;
typedef const struct _jc_soot_jimple_toolkits_typing_TypeAssigner$vtype	_jc_soot_jimple_toolkits_typing_TypeAssigner$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_typing_TypeAssigner$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_jimple_toolkits_typing_TypeAssigner$object *, struct _jc_soot_Singletons__24Global$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_toolkits_typing_TypeAssigner$method$internalTransform$9abd4924859b68a3(_jc_env *, struct _jc_soot_jimple_toolkits_typing_TypeAssigner$object *, struct _jc_soot_Body$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_jimple_toolkits_typing_TypeAssigner$method$typingFailed$1ce2325cbac8a787(_jc_env *, struct _jc_soot_jimple_toolkits_typing_TypeAssigner$object *, struct _jc_soot_jimple_JimpleBody$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_typing_TypeAssigner$method_info$internalTransform$9abd4924859b68a3;
extern _jc_method _jc_soot_jimple_toolkits_typing_TypeAssigner$method_info$typingFailed$1ce2325cbac8a787;

// Static methods
extern struct _jc_soot_jimple_toolkits_typing_TypeAssigner$object *_jc_soot_jimple_toolkits_typing_TypeAssigner$method$v$ddfa867c9204e3c5(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_typing_TypeAssigner$vmethods {
	void	(*internalTransform$9abd4924859b68a3)(_jc_env *, struct _jc_soot_jimple_toolkits_typing_TypeAssigner$object *, struct _jc_soot_Body$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;
	jboolean	(*typingFailed$1ce2325cbac8a787)(_jc_env *, struct _jc_soot_jimple_toolkits_typing_TypeAssigner$object *, struct _jc_soot_jimple_JimpleBody$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_typing_TypeAssigner$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Transformer$vmethods	soot_Transformer;
	_jc_soot_BodyTransformer$vmethods	soot_BodyTransformer;
	_jc_soot_jimple_toolkits_typing_TypeAssigner$vmethods	soot_jimple_toolkits_typing_TypeAssigner;
};

// Vtype
struct _jc_soot_jimple_toolkits_typing_TypeAssigner$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_typing_TypeAssigner$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_typing_TypeAssigner$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_typing_TypeAssigner$refs {
    _jc_soot_jimple_toolkits_typing_TypeAssigner$sub_refs	soot_jimple_toolkits_typing_TypeAssigner;
    _jc_soot_BodyTransformer$sub_refs	soot_BodyTransformer;
    _jc_soot_Transformer$sub_refs	soot_Transformer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_typing_TypeAssigner$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_typing_TypeAssigner$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Transformer$sub_nonrefs	soot_Transformer;
    _jc_soot_BodyTransformer$sub_nonrefs	soot_BodyTransformer;
    _jc_soot_jimple_toolkits_typing_TypeAssigner$sub_nonrefs	soot_jimple_toolkits_typing_TypeAssigner;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_typing_TypeAssigner$object {
	_jc_soot_jimple_toolkits_typing_TypeAssigner$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_typing_TypeAssigner$vtype	*vtype;
	_jc_soot_jimple_toolkits_typing_TypeAssigner$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_typing_TypeAssigner$vtype _jc_soot_jimple_toolkits_typing_TypeAssigner$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_typing_TypeAssigner, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_typing_TypeAssigner$class_object;

#endif	/* _JC_soot_jimple_toolkits_typing_TypeAssigner_H_ */
